@@ -1,4 +1,3 @@
-import functools
 import os
 import time
 
@@ -6,7 +5,6 @@ from locust import events,User
 
 from xlocust_bigquery.bigquery import query, load_data_gs_bucket_csv, load_data_gs_bucket_json
 from google.cloud import bigquery
-from google.cloud.bigquery.table import RowIterator, _EmptyRowIterator
 from google.oauth2 import service_account
 
 
@@ -18,8 +16,12 @@ class BQClientUser(User):
         super().__init__(environment)
 
     def client(self):
+
         account = os.environ.get("GOOGLE_APPLICATION_CREDENTIALS")
 
+        if account is None:
+            raise Exception("Please ensure that service account enviornment varible is set before using user")
+
         credentials = service_account.Credentials.from_service_account_file(account, scopes=[
             "https://www.googleapis.com/auth/cloud-platform"])
 
